# Generated by Django 3.2.9 on 2021-12-30 04:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("posts", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="NonQuillPost",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("content_char", models.CharField(blank=True, max_length=300)),
                ("content_text", models.TextField(blank=True)),
            ],
        ),
    ]
